summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteawayaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteawayaction.h')
-rw-r--r--kopete/libkopete/kopeteawayaction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteawayaction.h b/kopete/libkopete/kopeteawayaction.h
index 6bc64581..707750f6 100644
--- a/kopete/libkopete/kopeteawayaction.h
+++ b/kopete/libkopete/kopeteawayaction.h
@@ -44,23 +44,23 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
public:
/**
* Constructor
* @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const TQString &text, const TQIconSet &pix,
const KShortcut &cut, const TQObject *receiver, const char *slot,
- TQObject *tqparent, const char *name = 0);
+ TQObject *parent, const char *name = 0);
/**
* Constructor
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
* @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
* @p name are all handled by KSelectAction.
**/
AwayAction(const OnlineStatus &status, const TQString &text, const TQIconSet &pix,
const KShortcut &cut, const TQObject *receiver, const char *slot,
- TQObject *tqparent, const char *name = 0);
+ TQObject *parent, const char *name = 0);
/**
* Destructor.
@@ -44,23 +44,23 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
/**
* Constructor
- * @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
+ * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/
@@ -44,23 +44,23 @@ class KOPETE_EXPORT AwayAction : public KSelectAction
* @param status the OnlineStatus that appears in the signal
* @param slot must have the following signature: ( const OnlineStatus &, const TQString & )
- * @p text, @p pix, @p cut, @p receiver, @p slot, @p tqparent and
+ * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
* @p name are all handled by KSelectAction.
**/